#
# spec file for package hubble
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hubble
Version:        1.17.3
Release:        1.1
Summary:        Network, Service & Security Observability for Kubernetes using eBPF
License:        Apache-2.0
URL:            https://github.com/cilium/hubble
Source:         hubble-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23.6
BuildRequires:  zsh

%description
Hubble is a fully distributed networking and security observability platform
for cloud native workloads. It is built on top of Cilium and eBPF to enable
deep visibility into the communication and behavior of services as well as the
networking infrastructure in a completely transparent manner.

Hubble can answer questions such as:
  * Service dependencies & communication map:
    - What services are communicating with each other? How frequently? What
      does the service dependency graph look like?
    - What HTTP calls are being made? What Kafka topics does a service consume
      from or produce to?
  * Operational monitoring & alerting:
    - Is any network communication failing? Why is communication failing? Is it
      DNS? Is it an application or network problem? Is the communication broken
      on layer 4 (TCP) or layer 7 (HTTP)?
    - Which services have experienced a DNS resolution problems in the last 5
      minutes? Which services have experienced an interrupted TCP connection
      recently or have seen connections timing out? What is the rate of unanswered
      TCP SYN requests?
  * Application monitoring:
    - What is the rate of 5xx or 4xx HTTP response codes for a particular
      service or across all clusters?
    - What is the 95th and 99th percentile latency between HTTP requests and
      responses in my cluster? Which services are performing the worst? What is
      the latency between two services?
  * Security observability:
    - Which services had connections blocked due to network policy? What
      services have been accessed from outside the cluster? Which services have
      resolved a particular DNS name?

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/hubble.obsinfo)"
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/cilium/cilium/hubble/pkg.GitBranch=main \
   -X github.com/cilium/cilium/hubble/pkg.GitHash=${COMMIT_HASH:0:8} \
   -X github.com/cilium/cilium/hubble/pkg.Version=%{version}" \
   -o bin/hubble .

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri May  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.17.3:
  * Prepare for v1.17.3 release
  * chore(deps): update module golang.org/x/net to v0.38.0
    [security]
  * chore(deps): update library/golang docker tag to v1.24.2
  * chore(deps): update all github action dependencies
  * chore(deps): update library/golang docker tag to v1.23.8
  * README: Update latest version to 1.17.2
  * Update stable release to 1.17.2
* Wed Apr  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.17.2:
  * Prepare for v1.17.2 release
  * chore(deps): update actions/setup-go action to v5.4.0
  * chore(deps): update all github action dependencies
  * chore(deps): update module golang.org/x/net to v0.36.0
    [security]
  * chore(deps): update library/golang docker tag to v1.23.7
  * chore(deps): update dependency cilium/cilium to v1.17.1
  * chore(deps): update dependency helm/helm to v3.17.1
  * chore(deps): update dependency kubernetes-sigs/kind to v0.27.0
  * update stable release to 1.17.1
* Thu Feb 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.17.1:
  * Prepare for v1.17.1 release
  * migrate Renovate config take #2
  * migrate Renovate config
  * go.mod: require latest patch version
  * make: update Go to v1.23.6
  * Update stable release to 1.17.0
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.17.0:
  * Prepare for v1.17.0 release
  * chore(deps): update dependency cilium/cilium to v1.17.0
  * chore(deps): update actions/setup-go action to v5.3.0
  * chore(deps): update dependency cilium/cilium to v1.16.6
  * Update stable release to 1.16.6
* Thu Jan 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.16.6:
  * Prepare for v1.16.6 release
  * chore(deps): update dependency helm/helm to v3.17.0
  * chore(deps): update helm/kind-action action to v1.12.0
  * chore(deps): update all github action dependencies
  * chore(deps): update all github action dependencies
  * chore(deps): update module golang.org/x/net to v0.33.0
    [security]
  * Update stable release to v1.16.5
  * README: Update releases to include latest release
* Thu Dec 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.16.5:
  * Prepare for v1.16.5 release
  * chore(deps): update actions/setup-go action to v5.2.0
  * Remove Dockerfile
  * chore(deps): update golang to v1.23.4
  * chore(deps): update docker.io/library/alpine:3.21.0 docker
    digest to 21dc606
  * chore(deps): update docker.io/library/alpine docker tag to
    v3.21.0
  * chore(deps): update docker/build-push-action action to v6.10.0
  * release: Remove the step to post a Slack message
  * chore(deps): update dependency cilium/cilium to v1.16.4
  * Update stable release to 1.16.4
* Fri Nov 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.16.4:
  * Prepare for v1.16.4 release
  * chore(deps): update docker.io/library/alpine:3.20.3 docker
    digest to 1e42bbe
  * chore(deps): update golang
  * chore(deps): update dependency helm/helm to v3.16.3
  * chore(deps): update dependency kubernetes-sigs/kind to v0.25.0
  * chore(deps): update golang to v1.23.3
  * Update stable release to 1.16.3
* Tue Oct 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.16.3:
  * Prepare for v1.16.3 release
  * Remove the vendor team from CODEOWNERS
  * chore(deps): update actions/checkout action to v4.2.2
  * chore(deps): update actions/setup-go action to v5.1.0
  * chore(deps): update dependency cilium/cilium to v1.16.3
  * chore(deps): update all github action dependencies
  * Makefile: Use hubble target to build release binaries
  * Drop building 32-bit release binaries
  * Update the release issue template
  * Update stable release to 1.16.2
* Fri Oct  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.16.2:
  * Prepare for v1.16.2 release
  * chore(deps): update docker/setup-buildx-action action to v3.7.1
  * chore(deps): update all github action dependencies
  * chore(deps): update golang to v1.23.2
  * chore(deps): update docker/build-push-action action to v6.8.0
  * chore(deps): update dependency cilium/cilium to v1.16.2
  * chore(deps): update actions/checkout action to v4.2.0
  * chore(deps): update dependency ubuntu to v24
  * chore(deps): update golang
  * chore(deps): update dependency helm/helm to v3.16.1
  * chore(deps): update docker.io/library/alpine docker tag to
    v3.20.3
  * Update stable release to 1.16.1
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.16.1:
  * Prepare for v1.16.1 release
  * chore(deps): update golang to v1.23.1
  * chore(deps): update actions/upload-artifact action to v4.4.0
  * chore(deps): update all github action dependencies
  * chore(deps): update all github action dependencies
  * chore(deps): update golang to v1.23.0
  * chore(deps): update golang to v1.22.6
  * chore(deps): update docker/build-push-action action to v6.6.1
  * chore(deps): update actions/upload-artifact action to v4.3.6
  * chore(deps): update actions/upload-artifact action to v4.3.5
  * chore(deps): update docker/setup-buildx-action action to v3.6.1
  * doc: update slack channel reference
  * Remove v0.13 branch from Renovate config
  * Update stable release to 1.16.0
* Thu Jul 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.16.0:
  (no versions between 0.13.6 and this one)
  * Align version numbers with Cilium
  * Major Changes:
  - Move cilium/hubble code to cilium/cilium repo
    (cilium/cilium#31893, @michi-covalent)
  * Minor Changes:
  - hubble: node labels (cilium/cilium#32851, @kaworu)
  - hubble: support drop_reason_desc in flow filter
    (cilium/cilium#32135, @chaunceyjiang)
  * Misc Changes:
  - Add auto labeler for hubble-cli (cilium/cilium#32343, @aanm)
  - hive: Rebase on cilium/hive (cilium/cilium#32020, @bimmlerd)
  - hubble: Support --cel-expression filter in hubble observe
    (cilium/cilium#32147, @chancez)
* Thu Jul 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.13.6:
  * Modify version to 0.13.6
  * Modify changelog for 0.13.6 release
  * Bump golang to v1.21.12
  * chore(deps): update github/codeql-action action to v3.25.12
  * chore(deps): update all github action dependencies
  * chore(deps): update all github action dependencies
  * chore(deps): update all github action dependencies
  * chore(deps): update github/codeql-action action to v3.25.11
  * chore(deps): update docker/build-push-action action to v6.2.0
  * chore(deps): update golang stable
  * chore(deps): update golang stable
  * chore(deps): update docker/build-push-action action to v6
  * chore(deps): update docker.io/library/alpine docker tag to
    v3.19.2
  * chore(deps): update golang stable
  * chore(deps): update golang stable
  * chore(deps): update docker/build-push-action action to v5.4.0
  * chore(deps): update all github action dependencies
  * Prepare for v0.13.6 development
* Fri Jun  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.13.5:
  * Modify version to 0.13.5
  * Modify changelog for 0.13.5 release
  * Bump golang to v1.21.11
  * chore(deps): update github/codeql-action action to v3.25.8
  * chore(deps): update github/codeql-action action to v3.25.7
  * chore(deps): update docker/login-action action to v3.2.0
  * chore(deps): update all github action dependencies
  * chore(deps): update golang stable
  * Prepare for v0.13.5 development
* Tue May 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.13.4:
  * Modify version to 0.13.4
  * Modify changelog for 0.13.4 release
  * Bump Golang to v1.21.10
  * vendor: Bump Cilium to v1.15.4
  * chore(deps): update golangci/golangci-lint-action action to v6
  * chore(deps): update all github action dependencies
  * chore(deps): update golangci/golangci-lint-action action to
    v5.3.0
  * chore(deps): update actions/setup-go action to v5.0.1
  * chore(deps): update golangci/golangci-lint-action action to
    v5.1.0
  * chore(deps): update golangci/golangci-lint-action action to v5
  * chore(deps): update all github action dependencies
  * chore(deps): update helm/kind-action action to v1.10.0
  * chore(deps): update all github action dependencies
  * chore(deps): update github/codeql-action action to v3.25.1
  * CHANGELOG: Use correct year for the last few releases
  * Prepare for 0.13.4
* Thu Apr 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.13.3:
  * Modify version to 0.13.3
  * Modify changelog for 0.13.3 release
  * chore(deps): update docker/setup-buildx-action action to v3.3.0
  * chore(deps): update dependency helm/helm to v3.14.4
  * chore(deps): update github/codeql-action action to v3.24.10
  * chore(deps): update dependency cilium/cilium to v1.15.3
  * vendor: update cilium to v1.15.3
  * chore(deps): update github/codeql-action action to v3.24.9
  * chore(deps): update github/codeql-action action to v3.24.8
  * chore(deps): update golang stable
  * chore(deps): update all github action dependencies
  * chore(deps): update all github action dependencies
  * Prepare for 0.13.3
* Sat Mar 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package hubble: Network, Service & Security Observability for
  Kubernetes using eBPF
